# pysentel
> A python script for fetching 1-wire sensor-data and ingesting in InfluxDB.

[![PyPI version](https://badge.fury.io/py/pysentel.svg)](https://badge.fury.io/py/pysentel)

Python script fetching sensor-data from e.g. DS18B20-sensors via the 1-wire protocol and ingest these datapoints into a specified InfluxDB-bucket.


## Installation and setup

1. Install via `pip3 install pysentel`
2. Setup _WIP_


## Usage example
_Work-in-progress._


## Development setup
_Work-in-progress._


## Release History
- no releases yet.

## Meta

Danni Randeris - danni@danniranderis.dk

Distributed under the MIT license. See ``LICENSE`` for more information.

[https://github.com/danniranderis](https://github.com/danniranderis)


## Contributing

1. Fork it (<https://github.com/yourname/yourproject/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request